@@ -13,7 +13,9 @@ __title__ = 'gocomics'
 __author__ = 'Omkaar'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2022 Omkaar'
-__version__ = '1.0.4'
+__version__ = '1.1.1'
 
 
-from .comic import Comic
+from .comic import *
+from .list import *
+from .utils import *
